Crate filmreel

filmReel

A VCR specification implemented in Rust.

The filmreel crate is a pure Rust implementation of the declarative contract testing spec enjoying the memory safety property and other benefits from the Rust language.

Quick Start

Add the following to the Cargo.toml of your project:

[dependencies]
filmreel = "0.7"

Re-exports

pub use cut::Register;
pub use frame::Frame;
pub use reel::MetaFrame;
pub use reel::Reel;
pub use response::Response;
pub use vreel::VirtualReel;

Modules

cut
frame
reel
response
utils
vreel

Macros

from
Constructs a set of read instructions from strings meant associated with variables present in the Cut Register
register
Constructs a Cut Register from the provided series of key value pairs.
to
Constructs a set of read instructions from strings meant associated with variables present in the Cut Register
vframes

Enums

FrError
An error that occurred during parsing or hydrating a filmReel file

Traits

ToStringHidden
ToStringPretty
WithPath
adds the given filepath as context for FrError::File

Functions

file_to_reader
file_to_string
until_err